@@ -23,7 +23,8 @@ sys.path.insert(0, os.path.abspath('../..'))
 extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.todo',
-    'openstackdocstheme'
+    'openstackdocstheme',
+    'reno.sphinxext'
 ]
 
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
