@@ -16,23 +16,27 @@
 import os
 
 from kuryr.lib import utils
+from openstack import connection
 
 from kuryr_kubernetes import config
 from kuryr_kubernetes import k8s_client
-from neutronclient import client as n_client
 
 _clients = {}
 _NEUTRON_CLIENT = 'neutron-client'
-_LB_CLIENT = 'load-balancer-client'
 _KUBERNETES_CLIENT = 'kubernetes-client'
+_OPENSTACKSDK = 'openstacksdk'
 
 
 def get_neutron_client():
     return _clients[_NEUTRON_CLIENT]
 
 
+def get_openstacksdk():
+    return _clients[_OPENSTACKSDK]
+
+
 def get_loadbalancer_client():
-    return _clients[_LB_CLIENT]
+    return get_openstacksdk().load_balancer
 
 
 def get_kubernetes_client():
@@ -41,34 +45,14 @@ def get_kubernetes_client():
 
 def setup_clients():
     setup_neutron_client()
-    setup_loadbalancer_client()
     setup_kubernetes_client()
+    setup_openstacksdk()
 
 
 def setup_neutron_client():
     _clients[_NEUTRON_CLIENT] = utils.get_neutron_client()
 
 
-def setup_loadbalancer_client():
-    neutron_client = get_neutron_client()
-    if any(ext['alias'] == 'lbaasv2' for
-           ext in neutron_client.list_extensions()['extensions']):
-        _clients[_LB_CLIENT] = neutron_client
-        neutron_client.cascading_capable = False
-    else:
-        # Since Octavia is lbaasv2 API compatible (A superset of it) we'll just
-        # wire an extra neutron client instance to point to it
-        lbaas_client = utils.get_neutron_client()
-        conf_group = utils.kuryr_config.neutron_group.name
-        auth_plugin = utils.get_auth_plugin(conf_group)
-        octo_httpclient = n_client.construct_http_client(
-            session=utils.get_keystone_session(conf_group, auth_plugin),
-            service_type='load-balancer')
-        lbaas_client.httpclient = octo_httpclient
-        _clients[_LB_CLIENT] = lbaas_client
-        lbaas_client.cascading_capable = True
-
-
 def setup_kubernetes_client():
     if config.CONF.kubernetes.api_root:
         api_root = config.CONF.kubernetes.api_root
@@ -79,3 +63,10 @@ def setup_kubernetes_client():
         port = os.environ['KUBERNETES_SERVICE_PORT_HTTPS']
         api_root = "https://%s:%s" % (host, port)
     _clients[_KUBERNETES_CLIENT] = k8s_client.K8sClient(api_root)
+
+
+def setup_openstacksdk():
+    auth_plugin = utils.get_auth_plugin('neutron')
+    session = utils.get_keystone_session('neutron', auth_plugin)
+    conn = connection.Connection(session=session)
+    _clients[_OPENSTACKSDK] = conn
