@@ -26,7 +26,7 @@ MACVLAN_MODE_BRIDGE = 'bridge'
 
 
 @six.add_metaclass(abc.ABCMeta)
-class NestedDriver(health.HealthHandler):
+class NestedDriver(health.HealthHandler, b_base.BaseBindingDriver):
 
     def __init__(self):
         super(NestedDriver, self).__init__()
@@ -35,7 +35,7 @@ class NestedDriver(health.HealthHandler):
     def _get_iface_create_args(self, vif):
         raise NotImplementedError()
 
-    def connect(self, vif, ifname, netns):
+    def connect(self, vif, ifname, netns, container_id):
         with b_base.get_ipdb() as h_ipdb:
             # NOTE(vikasc): Ideally 'ifname' should be used here but instead a
             # temporary name is being used while creating the device for
@@ -62,7 +62,7 @@ class NestedDriver(health.HealthHandler):
                 iface.address = str(vif.address)
                 iface.up()
 
-    def disconnect(self, vif, ifname, netns):
+    def disconnect(self, vif, ifname, netns, container_id):
         # NOTE(vikasc): device will get deleted with container namespace, so
         # nothing to be done here.
         pass
