@@ -37,6 +37,7 @@ class NeutronPodVIFDriver(base.PodVIFDriver):
 
         rq = self._get_port_request(pod, project_id, subnets, security_groups)
         port = neutron.create_port(rq).get('port')
+        utils.tag_neutron_resources('ports', [port['id']])
         vif_plugin = self._get_vif_plugin(port)
 
         return ovu.neutron_to_osvif_vif(vif_plugin, port, subnets)
@@ -48,12 +49,13 @@ class NeutronPodVIFDriver(base.PodVIFDriver):
         rq = self._get_port_request(pod, project_id, subnets, security_groups,
                                     unbound=True)
 
-        bulk_port_rq = {'ports': [rq for _ in range(num_ports)]}
+        bulk_port_rq = {'ports': [rq] * num_ports}
         try:
             ports = neutron.create_port(bulk_port_rq).get('ports')
-        except n_exc.NeutronClientException as ex:
-            LOG.error("Error creating bulk ports: %s", bulk_port_rq)
-            raise ex
+        except n_exc.NeutronClientException:
+            LOG.exception("Error creating bulk ports: %s", bulk_port_rq)
+            raise
+        utils.tag_neutron_resources('ports', [port['id'] for port in ports])
 
         vif_plugin = self._get_vif_plugin(ports[0])
 
@@ -95,14 +97,16 @@ class NeutronPodVIFDriver(base.PodVIFDriver):
     def update_vif_sgs(self, pod, security_groups):
         neutron = clients.get_neutron_client()
         pod_state = utils.get_pod_state(pod)
-        # NOTE(ltomasbo): It just updates the default_vif security group
-        port_id = pod_state.vifs[constants.DEFAULT_IFNAME].id
-        neutron.update_port(port_id,
-                            {
-                                "port": {
-                                    'security_groups': list(security_groups)
-                                }
-                            })
+        if pod_state:
+            # NOTE(ltomasbo): It just updates the default_vif security group
+            port_id = pod_state.vifs[constants.DEFAULT_IFNAME].id
+            neutron.update_port(port_id,
+                                {
+                                    "port": {
+                                        'security_groups': list(
+                                            security_groups)
+                                    }
+                                })
 
     def _get_port_request(self, pod, project_id, subnets, security_groups,
                           unbound=False):
