@@ -177,7 +177,7 @@ class LoadBalancerHandler(k8s_base.ResourceEventHandler):
                       endpoints['metadata']['name'])
             return
 
-        lbaas_state = self._get_lbaas_state(endpoints)
+        lbaas_state = utils.get_lbaas_state(endpoints)
         if not lbaas_state:
             lbaas_state = obj_lbaas.LBaaSState()
 
@@ -209,7 +209,7 @@ class LoadBalancerHandler(k8s_base.ResourceEventHandler):
             # failing items, or validate configuration) to prevent annotation
             # being out of sync with the actual Neutron state.
             try:
-                self._set_lbaas_state(endpoints, lbaas_state)
+                utils.set_lbaas_state(endpoints, lbaas_state)
             except k_exc.K8sResourceNotFound:
                 # Note(yboaron) It's impossible to store neutron resources
                 # in K8S object since object was deleted. In that case
@@ -220,7 +220,7 @@ class LoadBalancerHandler(k8s_base.ResourceEventHandler):
 
     def on_deleted(self, endpoints, lbaas_state=None):
         if lbaas_state is None:
-            lbaas_state = self._get_lbaas_state(endpoints)
+            lbaas_state = utils.get_lbaas_state(endpoints)
         if not lbaas_state:
             return
         # NOTE(ivc): deleting pool deletes its members
@@ -387,10 +387,16 @@ class LoadBalancerHandler(k8s_base.ResourceEventHandler):
                             'namespace': target_ref['namespace']}}
         project_id = self._drv_pod_project.get_project(pod)
         subnets_map = self._drv_pod_subnets.get_subnets(pod, project_id)
-        # FIXME(ivc): potentially unsafe [0] index
-        return [subnet_id for subnet_id, network in subnets_map.items()
-                for subnet in network.subnets.objects
-                if ip in subnet.cidr][0]
+        subnet_ids = [subnet_id for subnet_id, network in subnets_map.items()
+                      for subnet in network.subnets.objects
+                      if ip in subnet.cidr]
+        if subnet_ids:
+            return subnet_ids[0]
+        else:
+            # NOTE(ltomasbo): We are assuming that if ip is not on the
+            # pod subnet is because the member is using hostnetworking. In
+            # this worker_nodes_subnet will be used
+            return config.CONF.pod_vif_nested.worker_nodes_subnet
 
     def _get_port_in_pool(self, pool, lbaas_state, lbaas_spec):
         for l in lbaas_state.listeners:
@@ -606,30 +612,3 @@ class LoadBalancerHandler(k8s_base.ResourceEventHandler):
         obj = obj_lbaas.LBaaSServiceSpec.obj_from_primitive(obj_dict)
         LOG.debug("Got LBaaSServiceSpec from annotation: %r", obj)
         return obj
-
-    def _set_lbaas_state(self, endpoints, lbaas_state):
-        # TODO(ivc): extract annotation interactions
-        if lbaas_state is None:
-            LOG.debug("Removing LBaaSState annotation: %r", lbaas_state)
-            annotation = None
-        else:
-            lbaas_state.obj_reset_changes(recursive=True)
-            LOG.debug("Setting LBaaSState annotation: %r", lbaas_state)
-            annotation = jsonutils.dumps(lbaas_state.obj_to_primitive(),
-                                         sort_keys=True)
-        k8s = clients.get_kubernetes_client()
-        k8s.annotate(endpoints['metadata']['selfLink'],
-                     {k_const.K8S_ANNOTATION_LBAAS_STATE: annotation},
-                     resource_version=endpoints['metadata']['resourceVersion'])
-
-    def _get_lbaas_state(self, endpoints):
-        # TODO(ivc): same as '_set_lbaas_state'
-        try:
-            annotations = endpoints['metadata']['annotations']
-            annotation = annotations[k_const.K8S_ANNOTATION_LBAAS_STATE]
-        except KeyError:
-            return None
-        obj_dict = jsonutils.loads(annotation)
-        obj = obj_lbaas.LBaaSState.obj_from_primitive(obj_dict)
-        LOG.debug("Got LBaaSState from annotation: %r", obj)
-        return obj
