@@ -129,8 +129,7 @@ class VIFHandler(k8s_base.ResourceEventHandler):
                 crd_pod_selectors = self._drv_sg.create_sg_rules(pod)
 
                 if self._is_network_policy_enabled():
-                    services = driver_utils.get_services(
-                        pod['metadata']['namespace'])
+                    services = driver_utils.get_services()
                     self._update_services(
                         services, crd_pod_selectors, project_id)
 
@@ -138,7 +137,7 @@ class VIFHandler(k8s_base.ResourceEventHandler):
         if driver_utils.is_host_network(pod):
             return
 
-        services = driver_utils.get_services(pod['metadata']['namespace'])
+        services = driver_utils.get_services()
         project_id = self._drv_project.get_project(pod)
         crd_pod_selectors = self._drv_sg.delete_sg_rules(pod)
         try:
