@@ -181,6 +181,34 @@ class TestNetworkPolicyDriver(test_base.TestCase):
         m_affected.assert_not_called()
         m_namespaced.assert_called_once_with(self._policy)
 
+    @mock.patch.object(network_policy.NetworkPolicyDriver, 'affected_pods')
+    @mock.patch.object(network_policy.NetworkPolicyDriver, 'namespaced_pods')
+    @mock.patch.object(network_policy.NetworkPolicyDriver,
+                       'get_kuryrnetpolicy_crd')
+    @mock.patch.object(network_policy.NetworkPolicyDriver,
+                       'create_security_group_rules_from_network_policy')
+    @mock.patch.object(network_policy.NetworkPolicyDriver,
+                       'update_security_group_rules_from_network_policy')
+    def test_ensure_network_policy_with_existing_crd_empty_selector(
+            self, m_update, m_create, m_get_crd, m_namespaced, m_affected):
+        previous_selector = {}
+        pod_selector = {'matchLabels': {'run': 'demo'}}
+        updated_policy = self._policy.copy()
+        updated_policy['spec']['podSelector'] = pod_selector
+        crd_with_empty_selector = self._crd.copy()
+        crd_with_empty_selector['spec']['podSelector'] = previous_selector
+
+        m_get_crd.return_value = crd_with_empty_selector
+        m_update.return_value = previous_selector
+
+        self._driver.ensure_network_policy(updated_policy, self._project_id)
+
+        m_get_crd.assert_called_once_with(updated_policy)
+        m_create.assert_not_called()
+        m_update.assert_called_once_with(updated_policy)
+        m_affected.assert_called_with(self._policy, previous_selector)
+        m_namespaced.assert_not_called()
+
     @mock.patch.object(network_policy.NetworkPolicyDriver,
                        '_add_default_np_rules')
     @mock.patch.object(network_policy.NetworkPolicyDriver,
@@ -196,7 +224,8 @@ class TestNetworkPolicyDriver(test_base.TestCase):
                                                              m_get_crd,
                                                              m_add_default):
         self._driver.neutron.create_security_group.return_value = {
-            'security_group': {'id': mock.sentinel.id}}
+            'security_group': {'id': mock.sentinel.id,
+                               'security_group_rules': []}}
         m_utils.get_subnet_cidr.return_value = {
             'subnet': {'cidr': mock.sentinel.cidr}}
         m_parse.return_value = (self._i_rules, self._e_rules)
@@ -221,7 +250,8 @@ class TestNetworkPolicyDriver(test_base.TestCase):
                                                       m_add_crd, m_get_crd,
                                                       m_add_default):
         self._driver.neutron.create_security_group.return_value = {
-            'security_group': {'id': mock.sentinel.id}}
+            'security_group': {'id': mock.sentinel.id,
+                               'security_group_rules': []}}
         m_utils.get_subnet_cidr.return_value = {
             'subnet': {'cidr': mock.sentinel.cidr}}
         m_parse.return_value = (self._i_rules, self._e_rules)
@@ -248,7 +278,8 @@ class TestNetworkPolicyDriver(test_base.TestCase):
                                                        m_add_crd, m_get_crd,
                                                        m_add_default):
         self._driver.neutron.create_security_group.return_value = {
-            'security_group': {'id': mock.sentinel.id}}
+            'security_group': {'id': mock.sentinel.id,
+                               'security_group_rules': []}}
         m_utils.get_subnet_cidr.return_value = {
             'subnet': {'cidr': mock.sentinel.cidr}}
         m_parse.return_value = (self._i_rules, self._e_rules)
@@ -359,10 +390,8 @@ class TestNetworkPolicyDriver(test_base.TestCase):
         policy['spec']['egress'] = [{}]
         self._driver.parse_network_policy_rules(policy, self._sg_id)
         m_get_ns_cidr.assert_not_called()
-        calls = [mock.call(self._sg_id, 'ingress', port_range_min=1,
-                           port_range_max=65535),
-                 mock.call(self._sg_id, 'egress', port_range_min=1,
-                           port_range_max=65535)]
+        calls = [mock.call(self._sg_id, 'ingress'),
+                 mock.call(self._sg_id, 'egress')]
         m_create.assert_has_calls(calls)
 
     @mock.patch.object(network_policy.NetworkPolicyDriver,
@@ -436,6 +465,13 @@ class TestNetworkPolicyDriver(test_base.TestCase):
         self._driver.affected_pods(self._policy, selector)
         m_namespaced.assert_not_called()
 
+    @mock.patch.object(network_policy.NetworkPolicyDriver, 'namespaced_pods')
+    def test_affected_pods_with_empty_podselector(self, m_namespaced):
+        m_namespaced.return_value = []
+        pod_selector = {}
+        self._driver.affected_pods(self._policy, pod_selector)
+        m_namespaced.assert_called_with(self._policy)
+
     def test_namespaced_pods(self):
         self.kubernetes.get.return_value = {'items': []}
 
