@@ -42,9 +42,11 @@ class TestVIFHandler(test_base.TestCase):
 
         self._pod_version = mock.sentinel.pod_version
         self._pod_link = mock.sentinel.pod_link
+        self._pod_namespace = mock.sentinel.namespace
         self._pod = {
             'metadata': {'resourceVersion': self._pod_version,
-                         'selfLink': self._pod_link},
+                         'selfLink': self._pod_link,
+                         'namespace': self._pod_namespace},
             'status': {'phase': k_const.K8S_POD_STATUS_PENDING},
             'spec': {'hostNetwork': False,
                      'nodeName': 'hostname'}
@@ -87,21 +89,25 @@ class TestVIFHandler(test_base.TestCase):
     @mock.patch.object(drivers.PodSecurityGroupsDriver, 'get_instance')
     @mock.patch.object(drivers.PodSubnetsDriver, 'get_instance')
     @mock.patch.object(drivers.PodProjectDriver, 'get_instance')
-    def test_init(self, m_get_project_driver, m_get_subnets_driver,
-                  m_get_sg_driver, m_get_vif_driver, m_get_vif_pool_driver,
-                  m_set_vifs_driver, m_get_multi_vif_drivers):
+    @mock.patch.object(drivers.LBaaSDriver, 'get_instance')
+    def test_init(self, m_get_lbaas_driver, m_get_project_driver,
+                  m_get_subnets_driver, m_get_sg_driver, m_get_vif_driver,
+                  m_get_vif_pool_driver, m_set_vifs_driver,
+                  m_get_multi_vif_drivers):
         project_driver = mock.sentinel.project_driver
         subnets_driver = mock.sentinel.subnets_driver
         sg_driver = mock.sentinel.sg_driver
         vif_driver = mock.sentinel.vif_driver
         vif_pool_driver = mock.Mock(spec=drivers.VIFPoolDriver)
         multi_vif_drivers = [mock.MagicMock(spec=drivers.MultiVIFDriver)]
+        lbaas_driver = mock.sentinel.lbaas_driver
         m_get_project_driver.return_value = project_driver
         m_get_subnets_driver.return_value = subnets_driver
         m_get_sg_driver.return_value = sg_driver
         m_get_vif_driver.return_value = vif_driver
         m_get_vif_pool_driver.return_value = vif_pool_driver
         m_get_multi_vif_drivers.return_value = multi_vif_drivers
+        m_get_lbaas_driver.return_value = lbaas_driver
 
         handler = h_vif.VIFHandler()
 
@@ -110,6 +116,7 @@ class TestVIFHandler(test_base.TestCase):
         self.assertEqual(sg_driver, handler._drv_sg)
         self.assertEqual(vif_pool_driver, handler._drv_vif_pool)
         self.assertEqual(multi_vif_drivers, handler._drv_multi_vif)
+        self.assertEqual(lbaas_driver, handler._drv_lbaas)
 
     def test_is_pending_node(self):
         self.assertTrue(h_vif.VIFHandler._is_pending_node(self._pod))
@@ -168,11 +175,14 @@ class TestVIFHandler(test_base.TestCase):
         self._activate_vif.assert_not_called()
         self._set_pod_state.assert_not_called()
 
+    @mock.patch('kuryr_kubernetes.controller.drivers.utils.get_services')
     @mock.patch('kuryr_kubernetes.controller.drivers.utils.is_host_network')
     @mock.patch('kuryr_kubernetes.controller.drivers.utils.get_pod_state')
-    def test_on_present_activate(self, m_get_pod_state, m_host_network):
+    def test_on_present_activate(self, m_get_pod_state, m_host_network,
+                                 m_get_services):
         m_get_pod_state.return_value = self._state
         m_host_network.return_value = False
+        m_get_services.return_value = {"items": []}
         self._vif.active = False
 
         h_vif.VIFHandler.on_present(self._handler, self._pod)
@@ -239,11 +249,13 @@ class TestVIFHandler(test_base.TestCase):
                                                   self._security_groups)
         self._activate_vif.assert_not_called()
 
+    @mock.patch('kuryr_kubernetes.controller.drivers.utils.get_services')
     @mock.patch('kuryr_kubernetes.controller.drivers.utils.is_host_network')
     @mock.patch('kuryr_kubernetes.controller.drivers.utils.get_pod_state')
-    def test_on_deleted(self, m_get_pod_state, m_host_network):
+    def test_on_deleted(self, m_get_pod_state, m_host_network, m_get_services):
         m_get_pod_state.return_value = self._state
         m_host_network.return_value = False
+        m_get_services.return_value = {"items": []}
         h_vif.VIFHandler.on_deleted(self._handler, self._pod)
 
         m_get_pod_state.assert_called_once_with(self._pod)
@@ -251,14 +263,16 @@ class TestVIFHandler(test_base.TestCase):
                                                   self._project_id,
                                                   self._security_groups)
 
+    @mock.patch('kuryr_kubernetes.controller.drivers.utils.get_services')
     @mock.patch('kuryr_kubernetes.controller.drivers.utils.is_host_network')
     @mock.patch('kuryr_kubernetes.controller.drivers.utils.get_pod_state')
     def test_on_deleted_with_additional_vifs(self, m_get_pod_state,
-                                             m_host_network):
+                                             m_host_network, m_get_services):
         additional_vif = os_obj.vif.VIFBase()
         self._state.additional_vifs = {'eth1': additional_vif}
         m_get_pod_state.return_value = self._state
         m_host_network.return_value = False
+        m_get_services.return_value = {"items": []}
 
         h_vif.VIFHandler.on_deleted(self._handler, self._pod)
 
@@ -280,11 +294,14 @@ class TestVIFHandler(test_base.TestCase):
         m_get_pod_state.assert_not_called()
         self._release_vif.assert_not_called()
 
+    @mock.patch('kuryr_kubernetes.controller.drivers.utils.get_services')
     @mock.patch('kuryr_kubernetes.controller.drivers.utils.is_host_network')
     @mock.patch('kuryr_kubernetes.controller.drivers.utils.get_pod_state')
-    def test_on_deleted_no_annotation(self, m_get_pod_state, m_host_network):
+    def test_on_deleted_no_annotation(self, m_get_pod_state, m_host_network,
+                                      m_get_services):
         m_get_pod_state.return_value = None
         m_host_network.return_value = False
+        m_get_services.return_value = {"items": []}
 
         h_vif.VIFHandler.on_deleted(self._handler, self._pod)
 
